@@ -1,53 +1,62 @@
-from base import QuickbooksBaseObject, Ref, QuickbooksManagedObject, QuickbooksTransactionEntity
+from base import QuickbooksBaseObject, Ref, QuickbooksManagedObject, QuickbooksTransactionEntity, \
+    LinkedTxnMixin
 from tax import TxnTaxDetail
-
-
-class Entity(QuickbooksBaseObject):
-    class_dict = {
-        "EntityRef": Ref
-    }
-
-    def __init__(self):
-        super(Entity, self).__init__()
-        self.Type = ""
-        self.EntityRef = None
+from detailline import DetailLine
 
 
 class JournalEntryLineDetail(QuickbooksBaseObject):
     class_dict = {
-        "AccountRef": Ref,
         "Entity": Ref
     }
 
     def __init__(self):
         super(JournalEntryLineDetail, self).__init__()
         self.PostingType = ""
+        self.TaxApplicableOn = ""
+        self.Type = ""
+        self.TaxAmount = 0
+        self.BillableStatus = ""
+
         self.Entity = None
+        self.EntityRef = None
         self.AccountRef = None
-
-    def __unicode__(self):
-        return self.PostingType
+        self.ClassRef = None
+        self.DepartmentRef = None
+        self.TaxCodeRef = None
 
 
-class JournalEntryLine(QuickbooksBaseObject):
+class JournalEntryLine(DetailLine):
     class_dict = {
         "JournalEntryLineDetail": JournalEntryLineDetail
     }
 
     def __init__(self):
         super(JournalEntryLine, self).__init__()
-        self.Description = ""
-        self.Amount = 0
-        self.Id = 0
-        self.LineNum = 0
         self.DetailType = "JournalEntryLineDetail"
         self.JournalEntryLineDetail = None
 
-    def __unicode__(self):
-        return str(self.Amount)
+
+class DescriptionLineDetail(QuickbooksBaseObject):
+    class_dict = {
+        "TaxCodeRef": Ref
+    }
+
+    def __init__(self):
+        super(DescriptionLineDetail, self).__init__()
+        self.ServiceDate = ""
 
 
-class JournalEntry(QuickbooksManagedObject, QuickbooksTransactionEntity):
+class DescriptionOnlyLine(DetailLine):
+    class_dict = {
+        "DescriptionLineDetail": DescriptionLineDetail
+    }
+
+    def __init__(self):
+        super(DescriptionOnlyLine, self).__init__()
+        self.DetailType = "DescriptionOnly"
+
+
+class JournalEntry(QuickbooksManagedObject, QuickbooksTransactionEntity, LinkedTxnMixin):
     """
     QBO definition: Journal Entry is a transaction in which:
         - There are at least two parts - a Debit and a Credit - called distribution lines.
@@ -59,7 +68,8 @@ class JournalEntry(QuickbooksManagedObject, QuickbooksTransactionEntity):
     """
 
     class_dict = {
-        "TxnTaxDetail": TxnTaxDetail
+        "TxnTaxDetail": TxnTaxDetail,
+        "CurrencyRef": Ref,
     }
 
     list_dict = {
@@ -72,9 +82,15 @@ class JournalEntry(QuickbooksManagedObject, QuickbooksTransactionEntity):
         super(JournalEntry, self).__init__()
         self.Adjustment = False
         self.TxnDate = ""
+        self.TxnSource = ""
+        self.DocNumber = ""
+        self.PrivateNote = ""
         self.TotalAmt = 0
+        self.ExchangeRate = 1
         self.Line = []
         self.TxnTaxDetail = None
 
+        self.CurrencyRef = None
+
     def __unicode__(self):
         return str(self.TotalAmt)
